@@ -26,14 +26,14 @@ ASAN_BUILD=0
 DEPLOY=1
 ENABLE_FREI0R=1
 FREI0R_HEAD=0
-FREI0R_REVISION="v2.3.0"
+FREI0R_REVISION="36e7da5d9e1f8b8cac9e97e204db1c5834fee580"
 ENABLE_MOVIT=1
 SUBDIRS=
 MOVIT_HEAD=0
 MOVIT_REVISION="origin/shotcut-opengl3"
 ENABLE_SWH_PLUGINS=0
 FFMPEG_HEAD=0
-FFMPEG_REVISION="origin/release/6.0"
+FFMPEG_REVISION="origin/release/7.0"
 FFMPEG_ADDITIONAL_OPTIONS=
 MLT_HEAD=1
 MLT_REVISION=
@@ -48,19 +48,22 @@ ENABLE_ZIMG=1
 ZIMG_HEAD=0
 ZIMG_REVISION="51c3c7f750c2af61955377faad56e3ba1b03589f"
 DAV1D_HEAD=0
-DAV1D_REVISION="1.2.0"
+DAV1D_REVISION="1.4.2"
 AOM_HEAD=0
-AOM_REVISION="v3.6.0"
+AOM_REVISION="v3.8.0"
 ENABLE_VMAF=1
 VMAF_HEAD=0
-VMAF_REVISION="v2.3.1"
+VMAF_REVISION="v3.0.0"
 ENABLE_GLAXNIMATE=1
 GLAXNIMATE_HEAD=0
-GLAXNIMATE_REVISION="v0.5.3"
+GLAXNIMATE_REVISION="origin/v0.5.4"
 ENABLE_GOPRO2GPX=1
 ENABLE_OPENCV=1
 OPENCV_HEAD=0
-OPENCV_REVISION="4.7.0"
+OPENCV_REVISION="4.9.0"
+ENABLE_LIBSPATIALAUDIO=1
+LIBSPATIALAUDIO_HEAD=1
+LIBSPATIALAUDIO_REVISION=
 
 # QT_INCLUDE_DIR="$(pkg-config --variable=prefix QtCore)/include"
 QT_INCLUDE_DIR=${QTDIR:+${QTDIR}/include}
@@ -186,6 +189,9 @@ function to_key {
     opencv_contrib)
       echo 16
     ;;
+    libspatialaudio)
+      echo 17
+    ;;
     *)
       echo UNKNOWN
     ;;
@@ -380,6 +386,9 @@ function set_globals {
     if test "$ENABLE_OPENCV" = 1 ; then
         SUBDIRS="opencv opencv_contrib $SUBDIRS"
     fi
+    if test "$ENABLE_LIBSPATIALAUDIO" = 1  && test "$LIBSPATIALAUDIO_HEAD" = 1 -o "$LIBSPATIALAUDIO_REVISION" != ""; then
+        SUBDIRS="libspatialaudio $SUBDIRS"
+    fi
     SUBDIRS="$SUBDIRS mlt shotcut"
   fi
 
@@ -422,6 +431,7 @@ function set_globals {
   REPOLOCS[14]="https://github.com/ddennedy/gopro2gpx.git"
   REPOLOCS[15]="https://github.com/opencv/opencv.git"
   REPOLOCS[16]="https://github.com/opencv/opencv_contrib.git"
+  REPOLOCS[17]="https://github.com/videolabs/libspatialaudio.git"
 
   # REPOTYPE Array holds the repo types. (Yes, this might be redundant, but easy for me)
   REPOTYPES[0]="git"
@@ -441,6 +451,7 @@ function set_globals {
   REPOTYPES[14]="git"
   REPOTYPES[15]="git"
   REPOTYPES[16]="git"
+  REPOTYPES[17]="git"
 
   # And, set up the revisions
   REVISIONS[0]=""
@@ -464,7 +475,7 @@ function set_globals {
     REVISIONS[4]="$SHOTCUT_REVISION"
   fi
   REVISIONS[5]="swh-plugins-0.4.15+1"
-  REVISIONS[6]="sdk/11.0" # nv-codec-headers
+  REVISIONS[6]="sdk/12.0" # nv-codec-headers
   REVISIONS[7]="" # AMF
   REVISIONS[8]=""
   if test 0 = "$BIGSH0T_HEAD" -a "$BIGSH0T_REVISION" ; then
@@ -499,6 +510,10 @@ function set_globals {
   if test 0 = "$OPENCV_HEAD" -a "$OPENCV_REVISION" ; then
     REVISIONS[16]="$OPENCV_REVISION"
   fi
+  REVISIONS[17]=""
+  if test 0 = "$LIBSPATIALAUDIO_HEAD" -a "$LIBSPATIALAUDIO_REVISION" ; then
+    REVISIONS[17]="$LIBSPATIALAUDIO_REVISION_REVISION"
+  fi
 
   # Figure out the number of cores in the system. Used both by make and startup script
   CPUS=$(nproc)
@@ -520,7 +535,7 @@ function set_globals {
 
   # set global environment for all jobs
   alias make=mingw32-make
-  export QTDIR="$HOME/Qt/6.4.3/mingw_64"
+  export QTDIR="$HOME/Qt/6.7.1/mingw_64"
   export PKG_CONFIG_PATH="$HOME/lib/pkgconfig:$PKG_CONFIG_PATH"
   export PATH="$FINAL_INSTALL_DIR/bin:$PATH"
   export LD_RUN_PATH="$FINAL_INSTALL_DIR/lib"
@@ -533,7 +548,7 @@ function set_globals {
   #####
   # ffmpeg
   CONFIG[0]="./configure --prefix=$FINAL_INSTALL_DIR --disable-static --disable-doc --enable-gpl --enable-version3 --enable-shared --enable-runtime-cpudetect $CONFIGURE_DEBUG_FLAG"
-  CONFIG[0]="${CONFIG[0]} --enable-libtheora --enable-libvorbis --enable-libmp3lame --enable-libx264 --enable-libx265 --enable-libvpx --enable-libopus --enable-libvpl --enable-libdav1d --enable-libaom --disable-decoder=libaom_av1 --enable-libwebp --disable-vulkan"
+  CONFIG[0]="${CONFIG[0]} --enable-libtheora --enable-libvorbis --enable-libmp3lame --enable-libx264 --enable-libx265 --enable-libvpx --enable-libopus --enable-libvpl --enable-libdav1d --enable-libaom --disable-decoder=libaom_av1 --enable-libsvtav1 --enable-libwebp --disable-vulkan --disable-vaapi"
   # Add optional parameters
   if [ "$ENABLE_ZIMG" = "1" ]; then
     CONFIG[0]="${CONFIG[0]} --enable-libzimg"
@@ -542,7 +557,7 @@ function set_globals {
     CONFIG[0]="${CONFIG[0]} --enable-libvmaf --disable-w32threads"
   fi
   CONFIG[0]="${CONFIG[0]} $FFMPEG_ADDITIONAL_OPTIONS"
-  CFLAGS_[0]="-I$FINAL_INSTALL_DIR/include $CFLAGS"
+  CFLAGS_[0]="-I$FINAL_INSTALL_DIR/include  -Wno-incompatible-pointer-types $CFLAGS"
 
   #####
   # mlt
@@ -677,6 +692,14 @@ function set_globals {
   LDFLAGS_[15]="$LDFLAGS"
   BUILD[15]="ninja -C build -j $MAKEJ"
   INSTALL[15]="ninja -C build install"
+
+  #####
+  # libspatialaudio
+  CONFIG[17]="cmake -G Ninja -B build -D CMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR $CMAKE_DEBUG_FLAG"
+  CFLAGS_[17]="$CFLAGS"
+  LDFLAGS_[17]="$LDFLAGS"
+  BUILD[17]="ninja -C build -j $MAKEJ"
+  INSTALL[17]="install_spatialaudio"
 }
 
 function build_dav1d {
@@ -693,8 +716,8 @@ function install_amf {
 function install_shotcut {
   cmd ninja install
   cmd install -c COPYING "$FINAL_INSTALL_DIR"
-  cmd install -c packaging/windows/shotcut.nsi "$FINAL_INSTALL_DIR"/..
-  cmd sed -i "s/YY.MM.DD/$SHOTCUT_VERSION/" "$FINAL_INSTALL_DIR"/../shotcut.nsi
+  cmd install -c packaging/windows/shotcut.iss "$FINAL_INSTALL_DIR"/..
+  cmd sed -i "s/YY.MM.DD/$SHOTCUT_VERSION/" "$FINAL_INSTALL_DIR"/../shotcut.iss
   cmd install -d "$FINAL_INSTALL_DIR"/share/translations
   cmd install -p -c translations/*.qm "$FINAL_INSTALL_DIR"/share/translations
 }
@@ -705,6 +728,12 @@ function install_vmaf {
   cmd install -p -c model/*.json "$FINAL_INSTALL_DIR"/share/vmaf || die "Unable to install $1"
 }
 
+function install_spatialaudio {
+  cmd ninja -C build install || die "Unable to install $1"
+  cmd sed -i "s,-I/mingw64/include,," "$FINAL_INSTALL_DIR"/lib/pkgconfig/spatialaudio.pc
+}
+
+
 ######################################################################
 # FEEDBACK FUNCTIONS
 ######################################################################
@@ -1088,17 +1117,6 @@ function sys_info {
   uname -a
   echo Information about cc at the time of compilation:
   LANG=C cc -v 2>&1
-  if which dpkg ; then
-    echo Found dpkg - running dpkg -l to grep libc6
-    dpkg -l | grep libc6
-  else
-    if which rpm ; then
-      echo Found rpm - running rpm -qa to grep libc6
-      rpm -qa | grep libc
-    else
-      echo Found neither dpkg or rpm...
-    fi
-  fi
 }
 
 
@@ -1164,7 +1182,7 @@ function deploy
 
   log Copying some libs from Qt
   if [ "$DEBUG_BUILD" != "1" -o "$SDK" = "1" ]; then
-    cmd cp -p "$QTDIR"/bin/Qt6{Core,Core5Compat,Gui,Multimedia,Network,OpenGL,OpenGLWidgets,Qml,QmlModels,QmlWorkerScript,Quick,QuickControls2,QuickControls2Impl,QuickDialogs2,QuickDialogs2QuickImpl,QuickDialogs2Utils,QuickLayouts,QuickTemplates2,QuickWidgets,Sql,Svg,SvgWidgets,UiTools,Widgets,Xml}.dll .
+    cmd cp -p "$QTDIR"/bin/Qt6{Charts,Core,Core5Compat,Gui,Multimedia,Network,OpenGL,OpenGLWidgets,Qml,QmlModels,QmlWorkerScript,Quick,QuickControls2*,QuickDialogs2,QuickDialogs2QuickImpl,QuickDialogs2Utils,QuickLayouts,QuickTemplates2,QuickWidgets,Sql,Svg,SvgWidgets,UiTools,Widgets,Xml}.dll .
   fi
 
   if [ "ENABLE_SWH_PLUGINS" != "1" ]; then
@@ -1181,12 +1199,12 @@ function deploy
   bundle_dlls glaxnimate.exe
 
   log Copying some DLLs and python libraries for Glaxnimate
-  cmd cp -p /mingw64/bin/libpython3.10.dll python310.dll
+  cmd cp -p /mingw64/bin/libpython3.11.dll python311.dll
   cmd cp -p "$SOURCE_DIR"/glaxnimate/external/Qt-Color-Widgets/libQtColorWidgets.dll .
   cmd mkdir -p share/glaxnimate/glaxnimate/pythonhome/lib/python
-  cmd cp -r /mingw64/lib/python3.10/*.py \
-            /mingw64/lib/python3.10/lib-dynload/* \
-            /mingw64/lib/python3.10/{json,collections,encodings,logging,urllib} \
+  cmd cp -r /mingw64/lib/python3.11/*.py \
+            /mingw64/lib/python3.11/lib-dynload/* \
+            /mingw64/lib/python3.11/{json,collections,encodings,logging,urllib} \
       share/glaxnimate/glaxnimate/pythonhome/lib/python
 
   log Copying some libs from mlt-prebuilt
@@ -1212,6 +1230,7 @@ function deploy
   cmd mkdir -p lib/qt6/audio
   for plugin in audio generic iconengines imageformats multimedia platforms sqldrivers styles tls; do
     cmd cp -pr "$QTDIR"/plugins/${plugin} lib/qt6
+    cmd rm lib/qt6/multimedia/ffmpegmediaplugin.dll
     for lib in lib/qt6/${plugin}/*.dll; do
       bundle_dlls "$lib"
     done
