@@ -28,7 +28,7 @@ ASAN_BUILD=0
 CREATE_STARTUP_SCRIPT=1
 ENABLE_FREI0R=1
 FREI0R_HEAD=0
-FREI0R_REVISION="v2.3.0"
+FREI0R_REVISION="36e7da5d9e1f8b8cac9e97e204db1c5834fee580"
 ENABLE_MOVIT=1
 SUBDIRS=
 MOVIT_HEAD=0
@@ -38,12 +38,12 @@ X264_REVISION="origin/stable"
 X265_HEAD=0
 X265_REVISION="origin/stable"
 LIBVPX_HEAD=0
-LIBVPX_REVISION="v1.12.0"
+LIBVPX_REVISION="v1.13.1"
 LIBOPUS_HEAD=0
-LIBOPUS_REVISION="v1.3.1"
+LIBOPUS_REVISION="v1.4"
 ENABLE_SWH_PLUGINS=1
 FFMPEG_HEAD=0
-FFMPEG_REVISION="origin/release/6.0"
+FFMPEG_REVISION="origin/release/7.0"
 FFMPEG_SUPPORT_H264=1
 FFMPEG_SUPPORT_H265=1
 FFMPEG_SUPPORT_JACK=1
@@ -59,6 +59,7 @@ FFMPEG_SUPPORT_QSV=1
 FFMPEG_SUPPORT_DAV1D=1
 FFMPEG_SUPPORT_AOM=1
 FFMPEG_SUPPORT_WEBP=1
+FFMPEG_SUPPORT_SVTAV1=1
 FFMPEG_SUPPORT_VMAF=1
 FFMPEG_ADDITIONAL_OPTIONS=
 ENABLE_VIDSTAB=1
@@ -72,7 +73,7 @@ SHOTCUT_REVISION=
 SHOTCUT_VERSION=$(date '+%y.%m.%d')
 ENABLE_RUBBERBAND=1
 RUBBERBAND_HEAD=0
-RUBBERBAND_REVISION="v3.2.1"
+RUBBERBAND_REVISION="v3.3.0"
 ENABLE_BIGSH0T=1
 BIGSH0T_HEAD=0
 BIGSH0T_REVISION="8fe56f6d4e"
@@ -80,24 +81,32 @@ ENABLE_ZIMG=1
 ZIMG_HEAD=0
 ZIMG_REVISION="51c3c7f750c2af61955377faad56e3ba1b03589f"
 DAV1D_HEAD=0
-DAV1D_REVISION="1.2.0"
+DAV1D_REVISION="1.4.2"
 AOM_HEAD=0
-AOM_REVISION="v3.6.0"
+AOM_REVISION="v3.8.0"
+SVTAV1_HEAD=0
+SVTAV1_REVISION="v2.1.0"
 VMAF_HEAD=0
-VMAF_REVISION="v2.3.1"
+VMAF_REVISION="v3.0.0"
 ENABLE_GLAXNIMATE=1
 GLAXNIMATE_HEAD=0
-GLAXNIMATE_REVISION="v0.5.3"
+GLAXNIMATE_REVISION="origin/v0.5.4"
 ENABLE_GOPRO2GPX=1
 ENABLE_OPENCV=1
 OPENCV_HEAD=0
-OPENCV_REVISION="4.7.0"
+OPENCV_REVISION="4.9.0"
+ENABLE_LIBWEBP=1
+LIBWEBP_HEAD=0
+LIBWEBP_REVISION="v1.3.2"
+ENABLE_LIBSPATIALAUDIO=1
+LIBSPATIALAUDIO_HEAD=1
+LIBSPATIALAUDIO_REVISION=
 
 PYTHON_VERSION_DEFAULT=3.8
-PYTHON_VERSION_DARWIN=3.10
+PYTHON_VERSION_DARWIN=3.11
 
 QT_VERSION_DEFAULT=6.4.3
-QT_VERSION_DARWIN=6.4.3
+QT_VERSION_DARWIN=6.7.1
 
 # QT_INCLUDE_DIR="$(pkg-config --variable=prefix QtCore)/include"
 QT_INCLUDE_DIR=${QTDIR:+${QTDIR}/include}
@@ -196,6 +205,9 @@ function to_key {
     movit)
       echo 5
     ;;
+    libspatialaudio)
+      echo 6
+    ;;
     shotcut)
       echo 7
     ;;
@@ -250,6 +262,12 @@ function to_key {
     opencv_contrib)
       echo 27
     ;;
+    libwebp)
+      echo 28
+    ;;
+    SVT-AV1)
+      echo 29
+    ;;
     *)
       echo UNKNOWN
     ;;
@@ -475,6 +493,9 @@ function set_globals {
     if test "$FFMPEG_SUPPORT_AOM" = 1 && test "$AOM_HEAD" = 1 -o "$AOM_REVISION" != ""; then
         SUBDIRS="aom $SUBDIRS"
     fi
+    if test "$FFMPEG_SUPPORT_SVTAV1" = 1 && test "$SVTAV1_HEAD" = 1 -o "$SVTAV1_REVISION" != ""; then
+        SUBDIRS="SVT-AV1 $SUBDIRS"
+    fi
     if test "$FFMPEG_SUPPORT_VMAF" = 1 && test "$VMAF_HEAD" = 1 -o "$VMAF_REVISION" != ""; then
         SUBDIRS="vmaf $SUBDIRS"
     fi
@@ -487,6 +508,12 @@ function set_globals {
     if test "$ENABLE_OPENCV" = 1 ; then
         SUBDIRS="opencv opencv_contrib $SUBDIRS"
     fi
+    if test "$ENABLE_LIBWEBP" = 1  && test "$LIBWEBP_HEAD" = 1 -o "$LIBWEBP_REVISION" != ""; then
+        SUBDIRS="libwebp $SUBDIRS"
+    fi
+    if test "$ENABLE_LIBSPATIALAUDIO" = 1  && test "$LIBSPATIALAUDIO_HEAD" = 1 -o "$LIBSPATIALAUDIO_REVISION" != ""; then
+        SUBDIRS="libspatialaudio $SUBDIRS"
+    fi
   fi
 
   if [ "$DEBUG_BUILD" = "1" ]; then
@@ -518,6 +545,7 @@ function set_globals {
   REPOLOCS[3]="https://github.com/mirror/x264.git"
   REPOLOCS[4]="https://chromium.googlesource.com/webm/libvpx.git"
   REPOLOCS[5]="https://github.com/ddennedy/movit.git"
+  REPOLOCS[6]="https://github.com/videolabs/libspatialaudio.git"
   REPOLOCS[7]="https://github.com/mltframework/shotcut.git"
   REPOLOCS[8]="https://github.com/swh/ladspa.git"
   REPOLOCS[10]="https://github.com/georgmartius/vid.stab.git"
@@ -536,6 +564,8 @@ function set_globals {
   REPOLOCS[25]="https://github.com/ddennedy/gopro2gpx.git"
   REPOLOCS[26]="https://github.com/opencv/opencv.git"
   REPOLOCS[27]="https://github.com/opencv/opencv_contrib.git"
+  REPOLOCS[28]="https://github.com/webmproject/libwebp.git"
+  REPOLOCS[29]="https://gitlab.com/AOMediaCodec/SVT-AV1.git"
 
   # REPOTYPE Array holds the repo types. (Yes, this might be redundant, but easy for me)
   REPOTYPES[0]="git"
@@ -544,6 +574,7 @@ function set_globals {
   REPOTYPES[3]="git"
   REPOTYPES[4]="git"
   REPOTYPES[5]="git"
+  REPOTYPES[6]="git"
   REPOTYPES[7]="git"
   REPOTYPES[8]="git"
   REPOTYPES[9]="git"
@@ -563,6 +594,8 @@ function set_globals {
   REPOTYPES[25]="git"
   REPOTYPES[26]="git"
   REPOTYPES[27]="git"
+  REPOTYPES[28]="git"
+  REPOTYPES[29]="git"
 
   # And, set up the revisions
   REVISIONS[0]=""
@@ -590,6 +623,10 @@ function set_globals {
   if test 0 = "$MOVIT_HEAD" -a "$MOVIT_REVISION" ; then
     REVISIONS[5]="$MOVIT_REVISION"
   fi
+  REVISIONS[6]=""
+  if test 0 = "$LIBSPATIALAUDIO_HEAD" -a "$LIBSPATIALAUDIO_REVISION" ; then
+    REVISIONS[6]="$LIBSPATIALAUDIO_REVISION_REVISION"
+  fi
   REVISIONS[7]=""
   if test 0 = "$SHOTCUT_HEAD" -a "$SHOTCUT_REVISION" ; then
     REVISIONS[7]="$SHOTCUT_REVISION"
@@ -607,7 +644,7 @@ function set_globals {
   if test 0 = "$X265_HEAD" -a "$X265_REVISION" ; then
     REVISIONS[13]="$X265_REVISION"
   fi
-  REVISIONS[15]="sdk/11.0" # nv-codec-headers
+  REVISIONS[15]="sdk/12.0" # nv-codec-headers
   REVISIONS[16]=""
   REVISIONS[17]="1.25"
   REVISIONS[18]=""
@@ -630,10 +667,6 @@ function set_globals {
   if test 0 = "$AOM_HEAD" -a "$AOM_REVISION" ; then
     REVISIONS[22]="$AOM_REVISION"
   fi
-  REVISIONS[22]=""
-  if test 0 = "$AOM_HEAD" -a "$AOM_REVISION" ; then
-    REVISIONS[22]="$AOM_REVISION"
-  fi
   REVISIONS[23]=""
   if test 0 = "$VMAF_HEAD" -a "$VMAF_REVISION" ; then
     REVISIONS[23]="$VMAF_REVISION"
@@ -651,6 +684,14 @@ function set_globals {
   if test 0 = "$OPENCV_HEAD" -a "$OPENCV_REVISION" ; then
     REVISIONS[27]="$OPENCV_REVISION"
   fi
+  REVISIONS[28]=""
+  if test 0 = "$LIBWEBP_HEAD" -a "$LIBWEBP_REVISION" ; then
+    REVISIONS[28]="$LIBWEBP_REVISION"
+  fi
+  REVISIONS[29]=""
+  if test 0 = "$SVTAV1_HEAD" -a "$SVTAV1_REVISION" ; then
+    REVISIONS[29]="$SVTAV1_REVISION"
+  fi
 
   # Figure out the number of cores in the system. Used both by make and startup script
   if test "$TARGET_OS" = "Darwin"; then
@@ -740,6 +781,9 @@ function set_globals {
   if test 1 = "$FFMPEG_SUPPORT_WEBP" ; then
     CONFIG[0]="${CONFIG[0]} --enable-libwebp"
   fi
+  if test 1 = "$FFMPEG_SUPPORT_SVTAV1" ; then
+    CONFIG[0]="${CONFIG[0]} --enable-libsvtav1"
+  fi
   if test 1 = "$FFMPEG_SUPPORT_VMAF" ; then
     CONFIG[0]="${CONFIG[0]} --enable-libvmaf"
   fi
@@ -748,7 +792,7 @@ function set_globals {
   fi
   # Add optional parameters
   CONFIG[0]="${CONFIG[0]} $FFMPEG_ADDITIONAL_OPTIONS"
-  CFLAGS_[0]="-I$FINAL_INSTALL_DIR/include $CFLAGS"
+  CFLAGS_[0]="-I$FINAL_INSTALL_DIR/include -Wno-incompatible-pointer-types $CFLAGS"
   LDFLAGS_[0]="-L$FINAL_INSTALL_DIR/lib $LDFLAGS"
   if test "$TARGET_OS" = "Darwin"; then
     CFLAGS_[0]="${CFLAGS_[0]} -I/opt/local/include"
@@ -763,15 +807,22 @@ function set_globals {
 
   #####
   # mlt
-  CONFIG[1]="cmake -GNinja -DCMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR -DCMAKE_PREFIX_PATH=$QTDIR -DMOD_QT=OFF -DMOD_QT6=ON -DMOD_GLAXNIMATE_QT6=ON -DMOD_GDK=OFF -DMOD_SDL1=OFF $CMAKE_DEBUG_FLAG"
+  CONFIG[1]="cmake -GNinja -DCMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR -DCMAKE_PREFIX_PATH=$QTDIR -DMOD_QT=OFF -DMOD_QT6=ON -DMOD_GLAXNIMATE_QT6=ON -DMOD_GDK=OFF -DMOD_SDL1=OFF"
   # Remember, if adding more of these, to update the post-configure check.
   [ "$ENABLE_OPENCV" = "1" ] && CONFIG[1]="${CONFIG[1]} -DMOD_OPENCV=ON"
   [ "$MLT_DISABLE_SOX" = "1" ] && CONFIG[1]="${CONFIG[1]} -DMOD_SOX=OFF"
   CFLAGS_[1]="-I$FINAL_INSTALL_DIR/include $ASAN_CFLAGS $CFLAGS"
   if [ "$TARGET_OS" = "Darwin" ]; then
     CONFIG[1]="${CONFIG[1]} -DCMAKE_OSX_ARCHITECTURES='arm64;x86_64'"
+    if [ "$DEBUG_BUILD" = "1" ]; then
+      CONFIG[1]="${CONFIG[1]} -DCMAKE_BUILD_TYPE=Debug"
+    else
+      CONFIG[1]="${CONFIG[1]} -DCMAKE_BUILD_TYPE=RelWithDebInfo"
+    fi
     CFLAGS_[1]="${CFLAGS_[1]} -I/opt/local/include"
     LDFLAGS_[1]="${LDFLAGS_[1]} -L/opt/local/lib/libomp"
+  else
+    CONFIG[1]="${CONFIG[1]} $CMAKE_DEBUG_FLAG"
   fi
   CXXFLAGS_[1]="${CFLAGS_[1]} -std=c++11"
   LDFLAGS_[1]="${LDFLAGS_[1]} -L$FINAL_INSTALL_DIR/lib $ASAN_LDFLAGS $LDFLAGS"
@@ -829,6 +880,15 @@ function set_globals {
   fi
   INSTALL[5]="make install"
 
+  #####
+  # libspatialaudio
+  CONFIG[6]="cmake -G Ninja -B build -D CMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR $CMAKE_DEBUG_FLAG"
+  [ "$TARGET_OS" = "Darwin" ] && CONFIG[6]="${CONFIG[6]} -DCMAKE_OSX_ARCHITECTURES='arm64;x86_64'"
+  CFLAGS_[6]="$CFLAGS"
+  LDFLAGS_[6]="$LDFLAGS"
+  BUILD[6]="ninja -C build -j $MAKEJ"
+  INSTALL[6]="ninja -C build install"
+
   #####
   # shotcut
   CONFIG[7]="cmake -G Ninja -D CMAKE_PREFIX_PATH=$QTDIR -D SHOTCUT_VERSION=$SHOTCUT_VERSION $CMAKE_DEBUG_FLAG"
@@ -984,10 +1044,10 @@ function set_globals {
 
   #####
   # glaxnimate
-  CONFIG[24]="cmake -G Ninja -DCMAKE_PREFIX_PATH=$QTDIR -DCMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR $CMAKE_DEBUG_FLAG"
+  CONFIG[24]="cmake -G Ninja -DCMAKE_PREFIX_PATH='$FINAL_INSTALL_DIR;$QTDIR' -DCMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR $CMAKE_DEBUG_FLAG"
   if [ "$TARGET_OS" = "Darwin" ]; then
     CONFIG[24]="${CONFIG[24]} -DCMAKE_OSX_ARCHITECTURES='arm64;x86_64'"
-    CONFIG[24]="${CONFIG[24]} -DPython3_EXECUTABLE=/opt/local/Library/Frameworks/Python.framework/Versions/${PYTHON_VERSION_DARWIN}/bin/python${PYTHON_VERSION_DARWIN} -D PYTHON_EXECUTABLE=/opt/local/Library/Frameworks/Python.framework/Versions/${PYTHON_VERSION_DARWIN}/bin/python${PYTHON_VERSION_DARWIN}"
+    CONFIG[24]="${CONFIG[24]} -DPython3_EXECUTABLE=/opt/local/Library/Frameworks/Python.framework/Versions/${PYTHON_VERSION_DARWIN}/bin/python${PYTHON_VERSION_DARWIN}"
   fi
   CFLAGS_[24]="$ASAN_CFLAGS $CFLAGS"
   LDFLAGS_[24]="$ASAN_LDFLAGS $LDFLAGS"
@@ -1011,6 +1071,24 @@ function set_globals {
   LDFLAGS_[26]="$LDFLAGS"
   BUILD[26]="ninja -C build -j $MAKEJ"
   INSTALL[26]="ninja -C build install"
+
+  #####
+  # libwebp
+  CONFIG[28]="cmake -B build -G Ninja -D CMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR -D BUILD_SHARED_LIBS=ON $CMAKE_DEBUG_FLAG"
+  [ "$TARGET_OS" = "Darwin" ] && CONFIG[28]="${CONFIG[28]} -D CMAKE_OSX_ARCHITECTURES='arm64;x86_64'"
+  CFLAGS_[28]="$CFLAGS"
+  LDFLAGS_[28]="$LDFLAGS"
+  BUILD[28]="ninja -C build -j $MAKEJ"
+  INSTALL[28]="ninja -C build install"
+
+  #####
+  # SVT-AV1
+  CONFIG[29]="cmake -B build -G Ninja -D CMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR $CMAKE_DEBUG_FLAG -D BUILD_SHARED_LIBS=ON -D BUILD_TESTING=OFF -D BUILD_APPS=OFF -D ENABLE_AVX512=ON"
+  [ "$TARGET_OS" = "Darwin" ] && CONFIG[29]="${CONFIG[29]} -D CMAKE_OSX_ARCHITECTURES='arm64;x86_64'"
+  CFLAGS_[29]=$CFLAGS
+  LDFLAGS_[29]=$LDFLAGS
+  BUILD[29]="ninja -C build -j $MAKEJ"
+  INSTALL[29]="ninja -C build install"
 }
 
 function build_ffmpeg_darwin {
@@ -1070,7 +1148,7 @@ function install_shotcut_linux {
   cmd install -p -c COPYING "$FINAL_INSTALL_DIR"
   cmd install -p -c "$QTDIR"/translations/qt_*.qm "$FINAL_INSTALL_DIR"/share/shotcut/translations
   cmd install -p -c "$QTDIR"/translations/qtbase_*.qm "$FINAL_INSTALL_DIR"/share/shotcut/translations
-  cmd install -p -c "$QTDIR"/lib/libQt6{Core,Core5Compat,DBus,Gui,Multimedia,Network,OpenGL,OpenGLWidgets,Qml,QmlModels,QmlWorkerScript,Quick,QuickControls2,QuickControls2Impl,QuickDialogs2,QuickDialogs2QuickImpl,QuickDialogs2Utils,QuickLayouts,QuickTemplates2,QuickWidgets,Sql,Svg,SvgWidgets,UiTools,Widgets,Xml,X11Extras,XcbQpa}.so.6 "$FINAL_INSTALL_DIR"/lib
+  cmd install -p -c "$QTDIR"/lib/libQt6{Charts,Core,Core5Compat,DBus,Gui,Multimedia,Network,OpenGL,OpenGLWidgets,Qml,QmlModels,QmlWorkerScript,Quick,QuickControls2*,QuickDialogs2,QuickDialogs2QuickImpl,QuickDialogs2Utils,QuickLayouts,QuickTemplates2,QuickWidgets,Sql,Svg,SvgWidgets,UiTools,Widgets,Xml,X11Extras,XcbQpa}.so.6 "$FINAL_INSTALL_DIR"/lib
   cmd install -p -c "$QTDIR"/lib/lib{icudata,icui18n,icuuc}.so* "$FINAL_INSTALL_DIR"/lib
   cmd install -d "$FINAL_INSTALL_DIR"/lib/qt6/sqldrivers
   cmd cp -a "$QTDIR"/plugins/{egldeviceintegrations,generic,iconengines,imageformats,multimedia,platforminputcontexts,platforms,platformthemes,tls,wayland-decoration-client,wayland-graphics-integration-client,wayland-shell-integration,xcbglintegrations} "$FINAL_INSTALL_DIR"/lib/qt6
@@ -1091,9 +1169,9 @@ function build_vmaf_darwin {
 function install_vmaf {
   if [ "$TARGET_OS" = "Darwin" ]; then
     cmd ninja install -C libvmaf/build-arm64
-    cmd rm "$FINAL_INSTALL_DIR"/lib/libvmaf.1.dylib
-    cmd lipo -create libvmaf/build-arm64/src/libvmaf.1.dylib libvmaf/build-x86_64/src/libvmaf.1.dylib -output "$FINAL_INSTALL_DIR"/lib/libvmaf.1.dylib
-    cmd install_name_tool -id "$FINAL_INSTALL_DIR"/lib/libvmaf.1.dylib "$FINAL_INSTALL_DIR"/lib/libvmaf.1.dylib
+    cmd rm "$FINAL_INSTALL_DIR"/lib/libvmaf.3.dylib
+    cmd lipo -create libvmaf/build-arm64/src/libvmaf.3.dylib libvmaf/build-x86_64/src/libvmaf.3.dylib -output "$FINAL_INSTALL_DIR"/lib/libvmaf.3.dylib
+    cmd install_name_tool -id "$FINAL_INSTALL_DIR"/lib/libvmaf.3.dylib "$FINAL_INSTALL_DIR"/lib/libvmaf.3.dylib
   else
     cmd ninja -C libvmaf/build install
   fi
@@ -1498,6 +1576,10 @@ function configure_compile_install_subproject {
       replace_rpath opencv_plot
       replace_rpath opencv_tracking
       replace_rpath opencv_video
+    elif [ "libspatialaudio" = "$1" ]; then
+      replace_rpath spatialaudio
+    elif [ "SVT-AV1" = "$1" ]; then
+    replace_rpath SvtAv1Enc
     elif [ "vid.stab" = "$1" ]; then
       cmd sed -e 's/-fopenmp//' -i .bak "$FINAL_INSTALL_DIR/lib/pkgconfig/vidstab.pc"
     fi
@@ -1664,6 +1746,7 @@ function bundle_libs
          ($3 !~ /\/libedit\./) &&
          ($3 !~ /\/libgio-2.0\./) &&
          ($3 !~ /\/libgmodule-2.0\./) &&
+         ($3 !~ /\/libpixman-1\./) &&
          ($3 !~ /\/libwayland/) \
          {print $3}')
   for lib in $libs; do
@@ -1884,7 +1967,7 @@ function deploy_mac
       dmg_name="$INSTALL_DIR/unsigned.dmg"
       cmd rm "$dmg_name" 2>/dev/null
       sync
-      cmd hdiutil create -fs HFS+ -srcfolder staging -volname Shotcut -format UDBZ -size 800m "$dmg_name"
+      cmd hdiutil create -fs HFS+ -srcfolder staging -volname Shotcut -format UDBZ -size 1500m "$dmg_name"
 
       if [ "$ACTION_CLEANUP" = "1" ]; then
         cmd rm -rf staging
@@ -2002,16 +2085,6 @@ End-of-shotcut-wrapper
 
   popd
 
-  log Creating desktop file in $TMPFILE
-  cp shotcut/packaging/linux/org.shotcut.Shotcut.desktop $TMPFILE
-  sed -i '1i #!/usr/bin/env xdg-open' $TMPFILE
-  sed -i 's|Exec=.*|Exec=sh -c "\$(dirname "%k")/Shotcut.app/shotcut "%F""|' $TMPFILE
-  sed -i 's|Icon=.*|Icon=applications-multimedia|' $TMPFILE
-  if test 0 != $? ; then
-    die "Unable to create desktop file"
-  fi
-  cp $TMPFILE "$FINAL_INSTALL_DIR/../Shotcut.desktop" || die "Unable to create desktop file - cp failed"
-
   feedback_status Done creating startup and environment script
 
   cmd pushd "$INSTALL_DIR"
