@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2023 Meltytech, LLC
+ * Copyright (c) 2012-2024 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 #include "dialogs/durationdialog.h"
 #include "dialogs/filedatedialog.h"
 #include "dialogs/longuitask.h"
+#include "dialogs/resourcedialog.h"
 #include "dialogs/slideshowgeneratordialog.h"
 #include "mainwindow.h"
 #include "settings.h"
@@ -48,7 +49,8 @@
 #include <QClipboard>
 #include <QActionGroup>
 
-static const int kInOutChangedTimeoutMs = 100;
+static const auto kInOutChangedTimeoutMs = 100;
+static const auto kTilePaddingPx = 10;
 
 #define kDetailedMode "detailed"
 #define kIconsMode "icons"
@@ -72,7 +74,7 @@ public:
         const QImage thumb = index.data(Qt::DecorationRole).value<QImage>();
         const QString setting = Settings.playlistThumbnails();
         const int lineHeight = painter->fontMetrics().height();
-        const bool roomEnoughForAllDetails = lineHeight * 5 < thumb.height();
+        const bool roomEnoughForAllDetails = lineHeight * 3 < thumb.height() + kTilePaddingPx;
         const QFont oldFont = painter->font();
         QFont boldFont(oldFont);
         boldFont.setBold(true);
@@ -99,7 +101,7 @@ public:
         painter->setFont(oldFont);
 
         QRect centeredTextRect = option.rect;
-        centeredTextRect.setHeight(lineHeight * (roomEnoughForAllDetails ? 5 : 3));
+        centeredTextRect.setHeight(lineHeight * (roomEnoughForAllDetails ? 3 : 2) + kTilePaddingPx);
         centeredTextRect.moveCenter(option.rect.center());
 
         QRect textRect = centeredTextRect;
@@ -122,10 +124,7 @@ public:
                                                                 PlaylistModel::FIELD_DURATION).toString()));
         if (roomEnoughForAllDetails) {
             textPoint.setY(textPoint.y() + lineHeight);
-            painter->drawText(textPoint, tr("In: %1").arg(index.data(PlaylistModel::FIELD_IN).toString()));
-            textPoint.setY(textPoint.y() + lineHeight);
-            painter->drawText(textPoint, tr("Start: %1").arg(index.data(
-                                                                 PlaylistModel::FIELD_START).toString()));
+            painter->drawText(textPoint, tr("Date: %1").arg(index.data(PlaylistModel::FIELD_DATE).toString()));
         }
     }
 
@@ -136,9 +135,8 @@ public:
         Q_UNUSED(index);
         const bool doubleHeight = Settings.playlistThumbnails() == "tall"
                                   || Settings.playlistThumbnails() == "large";
-        const int spacing = 10;
         return QSize(m_view->viewport()->width(),
-                     PlaylistModel::THUMBNAIL_HEIGHT * (doubleHeight ? 2 : 1) + spacing);
+                     PlaylistModel::THUMBNAIL_HEIGHT * (doubleHeight ? 2 : 1) + kTilePaddingPx);
     }
 
 private slots:
@@ -203,6 +201,13 @@ PlaylistDock::PlaylistDock(QWidget *parent) :
     QMenu *sortByMenu = m_mainMenu->addMenu(tr("Sort"));
     sortByMenu->addAction(Actions["playlistSortByNameAction"]);
     sortByMenu->addAction(Actions["playlistSortByDateAction"]);
+    QMenu *columnsMenu = m_mainMenu->addMenu(tr("Columns"));
+    columnsMenu->addAction(Actions["playlistColumnsToggleThumbnailsAction"]);
+    columnsMenu->addAction(Actions["playlistColumnsToggleClipAction"]);
+    columnsMenu->addAction(Actions["playlistColumnsToggleInAction"]);
+    columnsMenu->addAction(Actions["playlistColumnsToggleDurationAction"]);
+    columnsMenu->addAction(Actions["playlistColumnsToggleStartAction"]);
+    columnsMenu->addAction(Actions["playlistColumnsToggleDateAction"]);
     Actions.loadFromMenu(m_mainMenu);
 
     DockToolBar *toolbar = new DockToolBar(tr("Playlist Controls"));
@@ -438,17 +443,13 @@ void PlaylistDock::setupActions()
     action = new QAction(tr("Remove All"), this);
     action->setToolTip(tr("Remove all items from the playlist"));
     connect(action, &QAction::triggered, this, &PlaylistDock::onRemoveAllActionTriggered);
-    connect(this, &PlaylistDock::selectionChanged, action, [ = ]() {
-        action->setEnabled(m_model.rowCount() > 0);
-    });
+    action->setEnabled(m_model.rowCount() > 0);
     Actions.add("playlistRemoveAllAction", action);
 
     action = new QAction(tr("Select All"), this);
     action->setShortcut(QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_A));
     connect(action, &QAction::triggered, this, &PlaylistDock::onSelectAllActionTriggered);
-    connect(this, &PlaylistDock::selectionChanged, action, [ = ]() {
-        action->setEnabled(m_model.rowCount() > 0);
-    });
+    action->setEnabled(m_model.rowCount() > 0);
     Actions.add("playlistSelectAllAction", action);
 
     action = new QAction(tr("Select None"), this);
@@ -730,6 +731,60 @@ void PlaylistDock::setupActions()
         action->setEnabled(m_model.rowCount() > 8);
     });
     Actions.add("playlistSelectClip9Action", action);
+
+    action = new QAction(tr("Thumbnails"), this);
+    action->setChecked(Settings.playlistShowColumn("thumbnails"));
+    action->setCheckable(true);
+    connect(action, &QAction::triggered, this, [ = ](bool checked) {
+        Settings.setPlaylistShowColumn("thumbnails", checked);
+        ui->tableView->setColumnHidden(PlaylistModel::COLUMN_THUMBNAIL, !checked);
+    });
+    Actions.add("playlistColumnsToggleThumbnailsAction", action);
+
+    action = new QAction(tr("Clip"), this);
+    action->setChecked(Settings.playlistShowColumn("clip"));
+    action->setCheckable(true);
+    connect(action, &QAction::triggered, this, [ = ](bool checked) {
+        Settings.setPlaylistShowColumn("clip", checked);
+        ui->tableView->setColumnHidden(PlaylistModel::COLUMN_RESOURCE, !checked);
+    });
+    Actions.add("playlistColumnsToggleClipAction", action);
+
+    action = new QAction(tr("In"), this);
+    action->setChecked(Settings.playlistShowColumn("in"));
+    action->setCheckable(true);
+    connect(action, &QAction::triggered, this, [ = ](bool checked) {
+        Settings.setPlaylistShowColumn("in", checked);
+        ui->tableView->setColumnHidden(PlaylistModel::COLUMN_IN, !checked);
+    });
+    Actions.add("playlistColumnsToggleInAction", action);
+
+    action = new QAction(tr("Duration"), this);
+    action->setChecked(Settings.playlistShowColumn("duration"));
+    action->setCheckable(true);
+    connect(action, &QAction::triggered, this, [ = ](bool checked) {
+        Settings.setPlaylistShowColumn("duration", checked);
+        ui->tableView->setColumnHidden(PlaylistModel::COLUMN_DURATION, !checked);
+    });
+    Actions.add("playlistColumnsToggleDurationAction", action);
+
+    action = new QAction(tr("Start"), this);
+    action->setChecked(Settings.playlistShowColumn("start"));
+    action->setCheckable(true);
+    connect(action, &QAction::triggered, this, [ = ](bool checked) {
+        Settings.setPlaylistShowColumn("start", checked);
+        ui->tableView->setColumnHidden(PlaylistModel::COLUMN_START, !checked);
+    });
+    Actions.add("playlistColumnsToggleStartAction", action);
+
+    action = new QAction(tr("Date"), this);
+    action->setChecked(Settings.playlistShowColumn("date"));
+    action->setCheckable(true);
+    connect(action, &QAction::triggered, this, [ = ](bool checked) {
+        Settings.setPlaylistShowColumn("date", checked);
+        ui->tableView->setColumnHidden(PlaylistModel::COLUMN_DATE, !checked);
+    });
+    Actions.add("playlistColumnsToggleDateAction", action);
 }
 
 int PlaylistDock::position()
@@ -769,6 +824,27 @@ void PlaylistDock::replaceClipsWithHash(const QString &hash, Mlt::Producer &prod
     }
 }
 
+void PlaylistDock::getSelectionRange(int *start, int *end)
+{
+    Mlt::Playlist *playlist = m_model.playlist();
+    if (!playlist || !m_view->selectionModel()
+            || !m_view->selectionModel()->selectedIndexes().size() ) {
+        *start = -1;
+        *end = -1;
+        return;
+    }
+    // Find the earliest start and the latest end in the selection
+    *start = std::numeric_limits<int>::max();
+    *end = -1;
+    foreach (auto index, m_view->selectionModel()->selectedIndexes()) {
+        int row = index.row();
+        int clipStart = playlist->clip_start(row);
+        int clipEnd = clipStart + playlist->clip_length(row);
+        *start = qMin(*start, clipStart);
+        *end = qMax(*end, clipEnd);
+    }
+}
+
 void PlaylistDock::incrementIndex()
 {
     QModelIndex index = m_view->currentIndex();
@@ -1055,6 +1131,9 @@ void PlaylistDock::onPlaylistCreated()
 void PlaylistDock::onPlaylistLoaded()
 {
     onPlaylistCreated();
+    bool nonEmptyModel = m_model.rowCount() > 0;
+    Actions["playlistRemoveAllAction"]->setEnabled(nonEmptyModel);
+    Actions["playlistSelectAllAction"]->setEnabled(nonEmptyModel);
 }
 
 void PlaylistDock::onPlaylistModified()
@@ -1063,18 +1142,25 @@ void PlaylistDock::onPlaylistModified()
         ui->tableView->resizeColumnsToContents();
         m_blockResizeColumnsToContents = true;
     }
+    bool nonEmptyModel = m_model.rowCount() > 0;
+    Actions["playlistRemoveAllAction"]->setEnabled(nonEmptyModel);
+    Actions["playlistSelectAllAction"]->setEnabled(nonEmptyModel);
 }
 
 void PlaylistDock::onPlaylistCleared()
 {
     emit enableUpdate(false);
     m_blockResizeColumnsToContents = false;
+    bool nonEmptyModel = m_model.rowCount() > 0;
+    Actions["playlistRemoveAllAction"]->setEnabled(nonEmptyModel);
+    Actions["playlistSelectAllAction"]->setEnabled(nonEmptyModel);
 }
 
 void PlaylistDock::onDropped(const QMimeData *data, int row)
 {
     bool resetIndex = true;
     if (data && data->hasUrls()) {
+        ResourceDialog dialog(this);
         LongUiTask longTask(tr("Add Files"));
         int insertNextAt = row;
         bool first = true;
@@ -1114,7 +1200,9 @@ void PlaylistDock::onDropped(const QMimeData *data, int row)
                 if (first) {
                     first = false;
                     if (!MLT.producer() || !MLT.producer()->is_valid()) {
-                        MAIN.open(path, nullptr, false);
+                        Mlt::Properties properties;
+                        properties.set(kShotcutSkipConvertProperty, 1);
+                        MAIN.open(path, &properties, false);
                         if (MLT.producer() && MLT.producer()->is_valid()) {
                             producer = MLT.producer();
                             first = true;
@@ -1122,6 +1210,7 @@ void PlaylistDock::onDropped(const QMimeData *data, int row)
                     }
                 }
                 producer = MLT.setupNewProducer(producer);
+                producer->set(kShotcutSkipConvertProperty, 1);
                 if (!MLT.isLiveProducer(producer) || producer->get_int(kShotcutVirtualClip)) {
                     ProxyManager::generateIfNotExists(*producer);
                     if (row == -1)
@@ -1130,10 +1219,10 @@ void PlaylistDock::onDropped(const QMimeData *data, int row)
                         MAIN.undoStack()->push(new Playlist::InsertCommand(m_model, MLT.XML(producer), insertNextAt++));
                 } else {
                     LongUiTask::cancel();
-                    DurationDialog dialog(this);
-                    dialog.setDuration(MLT.profile().fps() * 5);
-                    if (dialog.exec() == QDialog::Accepted) {
-                        producer->set_in_and_out(0, dialog.duration() - 1);
+                    DurationDialog durationDialog(this);
+                    durationDialog.setDuration(MLT.profile().fps() * 5);
+                    if (durationDialog.exec() == QDialog::Accepted) {
+                        producer->set_in_and_out(0, durationDialog.duration() - 1);
                         if (row == -1)
                             MAIN.undoStack()->push(new Playlist::AppendCommand(m_model, MLT.XML(producer)));
                         else
@@ -1145,9 +1234,23 @@ void PlaylistDock::onDropped(const QMimeData *data, int row)
                     setIndex(0);
                     resetIndex = false;
                 }
+                dialog.add(producer);
                 delete producer;
             }
         }
+        if (Settings.showConvertClipDialog() && dialog.producerCount() > 1 && dialog.hasTroubleClips()) {
+            dialog.selectTroubleClips();
+            dialog.setWindowTitle(tr("Dropped Files"));
+            longTask.cancel();
+            dialog.exec();
+        } else if (Settings.showConvertClipDialog() && dialog.producerCount() == 1) {
+            Mlt::Producer producer = dialog.producer(0);
+            QString convertAdvice = Util::getConversionAdvice(&producer);
+            if (!convertAdvice.isEmpty()) {
+                longTask.cancel();
+                Util::offerSingleFileConversion(convertAdvice, &producer, this);
+            }
+        }
     } else if (data && data->hasFormat(Mlt::XmlMimeType)) {
         if (MLT.producer() && MLT.producer()->is_valid()) {
             if (MLT.producer()->type() == mlt_service_playlist_type) {
@@ -1214,6 +1317,7 @@ void PlaylistDock::onAddToTimelineActionTriggered()
 
 void PlaylistDock::onAddToSlideshowActionTriggered()
 {
+    MLT.pause();
     const QModelIndexList &indexes = m_view->selectionModel()->selectedIndexes();
     Mlt::Playlist playlist(MLT.profile());
     foreach (auto index, indexes) {
@@ -1274,6 +1378,17 @@ void PlaylistDock::updateViewMode()
         m_model.setViewMode(PlaylistModel::Detailed);
         m_view = ui->tableView;
         ui->tableView->setModel(&m_model);
+
+        ui->tableView->setColumnHidden(PlaylistModel::COLUMN_THUMBNAIL,
+                                       !Settings.playlistShowColumn("thumbnails"));
+        ui->tableView->setColumnHidden(PlaylistModel::COLUMN_RESOURCE,
+                                       !Settings.playlistShowColumn("clip"));
+        ui->tableView->setColumnHidden(PlaylistModel::COLUMN_IN, !Settings.playlistShowColumn("in"));
+        ui->tableView->setColumnHidden(PlaylistModel::COLUMN_DURATION,
+                                       !Settings.playlistShowColumn("duration"));
+        ui->tableView->setColumnHidden(PlaylistModel::COLUMN_START, !Settings.playlistShowColumn("start"));
+        ui->tableView->setColumnHidden(PlaylistModel::COLUMN_DATE, !Settings.playlistShowColumn("date"));
+
         ui->tableView->resizeColumnsToContents();
         ui->tableView->show();
 
