@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2023 Meltytech, LLC
+ * Copyright (c) 2011-2024 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -117,7 +117,7 @@ int Controller::setProducer(Mlt::Producer *producer, bool)
     return error;
 }
 
-int Controller::open(const QString &url, const QString &urlToSave)
+int Controller::open(const QString &url, const QString &urlToSave, bool skipConvert)
 {
     int error = checkFile(url);
     if (error) {
@@ -148,19 +148,12 @@ int Controller::open(const QString &url, const QString &urlToSave)
         }
         updatePreviewProfile();
         setPreviewScale(Settings.playerPreviewScale());
-        if ( url.endsWith(".mlt") ) {
+        if (url.endsWith(".mlt")) {
             // Load the number of audio channels being used when this project was created.
             int channels = newProducer->get_int(kShotcutProjectAudioChannels);
             if (!channels)
                 channels = 2;
             m_audioChannels = channels;
-            if (newProducer->get_int(kShotcutProjectFolder)) {
-                QFileInfo info(url);
-                setProjectFolder(info.absolutePath());
-                ProxyManager::removePending();
-            } else {
-                setProjectFolder(QString());
-            }
         }
         if (Util::isFpsDifferent(profile().fps(), fps) || (Settings.playerGPU()
                                                            && !profile().is_explicit())) {
@@ -175,6 +168,7 @@ int Controller::open(const QString &url, const QString &urlToSave)
                 m_url = urlToSave;
         }
         Producer *producer = setupNewProducer(newProducer);
+        producer->set(kShotcutSkipConvertProperty, skipConvert);
         delete newProducer;
         newProducer = producer;
     } else {
@@ -510,7 +504,6 @@ bool Controller::saveXML(const QString &filename, Service *service, bool withRel
         if (ignore)
             s.set("ignore_points", 0);
         c.set("time_format", "clock");
-        c.set("no_meta", 1);
         c.set("store", "shotcut");
         c.set("root", root.toUtf8().constData());
         c.set("no_root", 1);
@@ -818,6 +811,95 @@ void Controller::setOut(int out)
     }
 }
 
+class FixLengthPropertiesParser : public Mlt::Parser
+{
+public:
+    FixLengthPropertiesParser() : Mlt::Parser() {}
+
+    int on_start_filter(Mlt::Filter *)
+    {
+        return 0;
+    }
+    int on_start_producer(Mlt::Producer *)
+    {
+        return 0;
+    }
+    int on_end_producer(Mlt::Producer *s)
+    {
+        if (!::strchr(s->get("length"), ':'))
+            s->set("length", s->frames_to_time(s->get_int("length"), mlt_time_clock));
+        return 0;
+    }
+    int on_start_playlist(Mlt::Playlist *)
+    {
+        return 0;
+    }
+    int on_end_playlist(Mlt::Playlist *)
+    {
+        return 0;
+    }
+    int on_start_tractor(Mlt::Tractor *)
+    {
+        return 0;
+    }
+    int on_end_tractor(Mlt::Tractor *)
+    {
+        return 0;
+    }
+    int on_start_multitrack(Mlt::Multitrack *)
+    {
+        return 0;
+    }
+    int on_end_multitrack(Mlt::Multitrack *)
+    {
+        return 0;
+    }
+    int on_start_track()
+    {
+        return 0;
+    }
+    int on_end_track()
+    {
+        return 0;
+    }
+    int on_end_filter(Mlt::Filter *)
+    {
+        return 0;
+    }
+    int on_start_transition(Mlt::Transition *)
+    {
+        return 0;
+    }
+    int on_end_transition(Mlt::Transition *)
+    {
+        return 0;
+    }
+    int on_start_chain(Mlt::Chain *)
+    {
+        return 0;
+    }
+    int on_end_chain(Mlt::Chain *s)
+    {
+        if (!::strchr(s->get("length"), ':'))
+            s->set("length", s->frames_to_time(s->get_int("length"), mlt_time_clock));
+        return 0;
+    }
+    int on_start_link(Mlt::Link *)
+    {
+        return 0;
+    }
+    int on_end_link(Mlt::Link *)
+    {
+        return 0;
+    }
+};
+
+void Controller::fixLengthProperties(Service &service)
+{
+    FixLengthPropertiesParser parser;
+    parser.start(service);
+}
+
 void Controller::restart(const QString &xml)
 {
     if (!m_consumer || !m_consumer->is_valid() || !m_producer || !m_producer->is_valid())
@@ -1161,9 +1243,13 @@ void Controller::adjustFilters(Producer &producer, int index)
                     QmlMetadata *meta = MAIN.filterController()->metadataForService(filter.data());
                     if (meta && meta->keyframes()) {
                         foreach (QString name, meta->keyframes()->simpleProperties()) {
-                            if (!filter->get_animation(name.toUtf8().constData()))
+                            if (!filter->get_animation(name.toUtf8().constData())) {
                                 // Cause a string property to be interpreted as animated value.
-                                filter->anim_get_double(name.toUtf8().constData(), 0, filter->get_length());
+                                if (meta->keyframes()->parameter(name)->isColor())
+                                    filter->anim_get_color(name.toUtf8().constData(), 0, filter->get_length());
+                                else
+                                    filter->anim_get_double(name.toUtf8().constData(), 0, filter->get_length());
+                            }
                             Mlt::Animation animation = filter->get_animation(name.toUtf8().constData());
                             if (animation.is_valid()) {
                                 int n = animation.key_count();
@@ -1205,6 +1291,9 @@ static void shiftKeyframes(Mlt::Service *service, QmlMetadata *meta, int delta)
                 if (paramMeta->isRectangle()) {
                     auto value = service->anim_get_rect(qUtf8Printable(name), delta);
                     service->anim_set(qUtf8Printable(name), value, delta, 0, existingType);
+                } else if (paramMeta->isColor()) {
+                    auto value = service->anim_get_color(qUtf8Printable(name), delta);
+                    service->anim_set(qUtf8Printable(name), value, delta, 0, existingType);
                 } else {
                     double value = service->anim_get_double(qUtf8Printable(name), delta);
                     service->anim_set(qUtf8Printable(name), value, delta, 0, existingType);
@@ -1245,7 +1334,8 @@ static void shiftKeyframes(Mlt::Service *service, QmlMetadata *meta, int delta)
             animation.shift_frames(-delta);
             foreach (QString gangName, paramMeta->gangedProperties()) {
                 Mlt::Animation gangAnim = service->get_animation(qUtf8Printable(gangName));
-                gangAnim.shift_frames(-delta);
+                if (gangAnim.is_valid())
+                    gangAnim.shift_frames(-delta);
             }
         }
     }
@@ -1339,9 +1429,13 @@ void Controller::adjustFilter(Mlt::Filter *filter, int in, int out, int inDelta,
             // Update simple keyframes
             if (filter->get_int(kShotcutAnimOutProperty) && meta && meta->keyframes()) {
                 foreach (QString name, meta->keyframes()->simpleProperties()) {
-                    if (!filter->get_animation(name.toUtf8().constData()))
+                    if (!filter->get_animation(name.toUtf8().constData())) {
                         // Cause a string property to be interpreted as animated value.
-                        filter->anim_get_double(name.toUtf8().constData(), 0, filter->get_length());
+                        if (meta->keyframes()->parameter(name)->isColor())
+                            filter->anim_get_color(name.toUtf8().constData(), 0, filter->get_length());
+                        else
+                            filter->anim_get_double(name.toUtf8().constData(), 0, filter->get_length());
+                    }
                     Mlt::Animation animation = filter->get_animation(name.toUtf8().constData());
                     if (animation.is_valid()) {
                         int n = animation.key_count();
@@ -1540,7 +1634,8 @@ int Controller::checkFile(const QString &path)
 {
     int error = 0;
     if (path.endsWith(".json") || path.endsWith(".rawr") || path.endsWith(".lottie")
-            || path.endsWith(".tgs")) {
+            || path.endsWith(".riv") || path.endsWith(".tgs") || path.endsWith(".avd")
+            || path.endsWith(".aep")) {
         QString shotcutPath = qApp->applicationDirPath();
 #if defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
         QFileInfo meltPath(shotcutPath, "melt-7");
