@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013-2023 Meltytech, LLC
+ * Copyright (c) 2013-2024 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -110,6 +110,13 @@ void ShotcutSettings::log()
     LOG_INFO() << "video mode" << playerProfile();
     LOG_INFO() << "realtime" << playerRealtime();
     LOG_INFO() << "audio channels" << playerAudioChannels();
+#if defined(Q_OS_WIN) || defined(Q_OS_LINUX)
+    if (::qEnvironmentVariableIsSet("SDL_AUDIODRIVER")) {
+        LOG_INFO() << "audio driver" <<::qgetenv("SDL_AUDIODRIVER");
+    } else {
+        LOG_INFO() << "audio driver" << playerAudioDriver();
+    }
+#endif
 }
 
 QString ShotcutSettings::language() const
@@ -565,6 +572,25 @@ void ShotcutSettings::setPlayerJumpSeconds(double i)
     settings.setValue("player/jumpSeconds", i);
 }
 
+QString ShotcutSettings::playerAudioDriver() const
+{
+#if defined(Q_OS_WIN)
+    auto s = playerAudioChannels() > 2 ? "directsound" : "winmm";
+#else
+    auto s = "pulseaudio";
+#endif
+    if (::qEnvironmentVariableIsSet("SDL_AUDIODRIVER")) {
+        return ::qgetenv("SDL_AUDIODRIVER");
+    } else {
+        return settings.value("player/audioDriver", s).toString();
+    }
+}
+
+void ShotcutSettings::setPlayerAudioDriver(const QString &s)
+{
+    settings.setValue("player/audioDriver", s);
+}
+
 QString ShotcutSettings::playlistThumbnails() const
 {
     return settings.value("playlist/thumbnails", "small").toString();
@@ -586,6 +612,16 @@ void ShotcutSettings::setPlaylistAutoplay(bool b)
     settings.setValue("playlist/autoplay", b);
 }
 
+bool ShotcutSettings::playlistShowColumn(const QString &column)
+{
+    return settings.value("playlist/columns/" + column, true).toBool();
+}
+
+void ShotcutSettings::setPlaylistShowColumn(const QString &column, bool b)
+{
+    settings.setValue("playlist/columns/" + column, b);
+}
+
 bool ShotcutSettings::timelineDragScrub() const
 {
     return settings.value("timeline/dragScrub", false).toBool();
@@ -663,17 +699,6 @@ void ShotcutSettings::setTimelineSnap(bool b)
     emit timelineSnapChanged();
 }
 
-bool ShotcutSettings::timelineCenterPlayhead() const
-{
-    return settings.value("timeline/centerPlayhead", false).toBool();
-}
-
-void ShotcutSettings::setTimelineCenterPlayhead(bool b)
-{
-    settings.setValue("timeline/centerPlayhead", b);
-    emit timelineCenterPlayheadChanged();
-}
-
 int ShotcutSettings::timelineTrackHeight() const
 {
     return qMin(settings.value("timeline/trackHeight", 50).toInt(), kMaximumTrackHeight);
@@ -734,6 +759,47 @@ void ShotcutSettings::setTimelinePreviewTransition(bool b)
     settings.setValue("timeline/previewTransition", b);
 }
 
+void ShotcutSettings::setTimelineScrolling(ShotcutSettings::TimelineScrolling value)
+{
+    settings.remove("timeline/centerPlayhead");
+    settings.setValue("timeline/scrolling", value);
+    emit timelineScrollingChanged();
+}
+
+ShotcutSettings::TimelineScrolling ShotcutSettings::timelineScrolling() const
+{
+    if (settings.contains("timeline/centerPlayhead")
+            && settings.value("timeline/centerPlayhead").toBool())
+        return ShotcutSettings::TimelineScrolling::CenterPlayhead;
+    else
+        return ShotcutSettings::TimelineScrolling(settings.value("timeline/scrolling",
+                                                                 PageScrolling).toInt());
+}
+
+bool ShotcutSettings::timelineAutoAddTracks() const
+{
+    return settings.value("timeline/autoAddTracks", false).toBool();
+}
+
+void ShotcutSettings::setTimelineAutoAddTracks(bool b)
+{
+    if (b != timelineAutoAddTracks()) {
+        settings.setValue("timeline/autoAddTracks", b);
+        emit timelineAutoAddTracksChanged();
+    }
+}
+
+bool ShotcutSettings::timelineRectangleSelect() const
+{
+    return settings.value("timeline/rectangleSelect", true).toBool();
+}
+
+void ShotcutSettings::setTimelineRectangleSelect(bool b)
+{
+    settings.setValue("timeline/rectangleSelect", b);
+    emit timelineRectangleSelectChanged();
+}
+
 QString ShotcutSettings::filterFavorite(const QString &filterName)
 {
     return settings.value("filter/favorite/" + filterName, "").toString();
@@ -1138,6 +1204,77 @@ QList<QKeySequence> ShotcutSettings::shortcuts(const QString &name)
     return shortcuts;
 }
 
+double ShotcutSettings::slideshowClipDuration(double defaultClipDuration) const
+{
+    return settings.value("slideshow/clipDuration", defaultClipDuration).toDouble();
+}
+
+void ShotcutSettings::setSlideshowClipDuration(double clipDuration)
+{
+    settings.setValue("slideshow/clipDuration", clipDuration);
+}
+
+int ShotcutSettings::slideshowAspectConversion(int defaultAspectConversion) const
+{
+    return settings.value("slideshow/aspectConversion", defaultAspectConversion).toInt();
+}
+
+void ShotcutSettings::setSlideshowAspectConversion(int aspectConversion)
+{
+    settings.setValue("slideshow/aspectConversion", aspectConversion);
+}
+
+int ShotcutSettings::slideshowZoomPercent(int defaultZoomPercent) const
+{
+    return settings.value("slideshow/zoomPercent", defaultZoomPercent).toInt();
+}
+
+void ShotcutSettings::setSlideshowZoomPercent(int zoomPercent)
+{
+    settings.setValue("slideshow/zoomPercent", zoomPercent);
+}
+
+double ShotcutSettings::slideshowTransitionDuration(double defaultTransitionDuration) const
+{
+    return settings.value("slideshow/transitionDuration", defaultTransitionDuration).toDouble();
+}
+
+void ShotcutSettings::setSlideshowTransitionDuration(double transitionDuration)
+{
+    settings.setValue("slideshow/transitionDuration", transitionDuration);
+}
+
+int ShotcutSettings::slideshowTransitionStyle(int defaultTransitionStyle) const
+{
+    return settings.value("slideshow/transitionStyle", defaultTransitionStyle).toInt();
+}
+
+void ShotcutSettings::setSlideshowTransitionStyle(int transitionStyle)
+{
+    settings.setValue("slideshow/transitionStyle", transitionStyle);
+}
+
+int ShotcutSettings::slideshowTransitionSoftness(int defaultTransitionStyle) const
+{
+    return settings.value("slideshow/transitionSoftness", defaultTransitionStyle).toInt();
+}
+
+void ShotcutSettings::setSlideshowTransitionSoftness(int transitionSoftness)
+{
+    settings.setValue("slideshow/transitionSoftness", transitionSoftness);
+}
+
+bool ShotcutSettings::keyframesDragScrub() const
+{
+    return settings.value("keyframes/dragScrub", false).toBool();
+}
+
+void ShotcutSettings::setKeyframesDragScrub(bool b)
+{
+    settings.setValue("keyframes/dragScrub", b);
+    emit keyframesDragScrubChanged();
+}
+
 void ShotcutSettings::reset()
 {
     for (auto &key : settings.allKeys()) {
@@ -1147,10 +1284,31 @@ void ShotcutSettings::reset()
 
 int ShotcutSettings::undoLimit() const
 {
-    return settings.value("undoLimit", 1000).toInt();
+    return settings.value("undoLimit", 50).toInt();
 }
 
 bool ShotcutSettings::warnLowMemory() const
 {
     return settings.value("warnLowMemory", true).toBool();
 }
+
+int ShotcutSettings::backupPeriod() const
+{
+    return settings.value("backupPeriod", 24 * 60).toInt();
+}
+
+void ShotcutSettings::setBackupPeriod(int minutes)
+{
+    settings.setValue("backupPeriod", minutes);
+}
+
+mlt_time_format ShotcutSettings::timeFormat() const
+{
+    return (mlt_time_format)settings.value("timeFormat", mlt_time_smpte_df).toInt();
+}
+
+void ShotcutSettings::setTimeFormat(int format)
+{
+    settings.setValue("timeFormat", format);
+    emit timeFormatChanged();
+}
