@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2023 Meltytech, LLC
+ * Copyright (c) 2014-2024 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,11 +41,13 @@
 #include <MltChain.h>
 #include <MltProducer.h>
 #include <Logger.h>
+#include "dialogs/transcodedialog.h"
 #include "mainwindow.h"
 #include "shotcut_mlt_properties.h"
 #include "qmltypes/qmlapplication.h"
 #include "proxymanager.h"
 #include "settings.h"
+#include "transcoder.h"
 
 #include <math.h>
 #include <memory>
@@ -375,7 +377,8 @@ void Util::applyCustomProperties(Mlt::Producer &destination, Mlt::Producer &sour
     p.clear(kOriginalOutProperty);
     if (!p.get_int(kIsProxyProperty))
         p.clear(kOriginalResourceProperty);
-    destination.pass_list(source, "mlt_service, audio_index, video_index, force_progressive, force_tff,"
+    destination.pass_list(source,
+                          "mlt_service, audio_index, video_index, astream, vstream, force_progressive, force_tff,"
                           "force_aspect_ratio, video_delay, color_range, warp_speed, warp_pitch, rotate,"
                           kAspectRatioNumerator ","
                           kAspectRatioDenominator ","
@@ -685,7 +688,7 @@ QString Util::updateCaption(Mlt::Producer *producer)
 
 void Util::passProducerProperties(Mlt::Producer *src, Mlt::Producer *dst)
 {
-    dst->pass_list(*src, "audio_index, video_index, force_aspect_ratio,"
+    dst->pass_list(*src, "audio_index, video_index, astream, vstream, force_aspect_ratio,"
                    "video_delay, force_progressive, force_tff, force_full_range, color_range, warp_pitch, rotate,"
                    kAspectRatioNumerator ","
                    kAspectRatioDenominator ","
@@ -737,3 +740,122 @@ bool Util::isFpsDifferent(double a, double b)
 {
     return qAbs(a - b) > 0.001;
 }
+
+QString Util::getNextFile(const QString &filePath)
+{
+    QFileInfo info(filePath);
+    QString basename = info.completeBaseName();
+    QString extension = info.suffix();
+    if (extension.isEmpty()) {
+        extension = basename;
+        basename = QString();
+    }
+    for (unsigned i = 1; i < std::numeric_limits<unsigned>::max(); i++) {
+        QString filename = QString::fromLatin1("%1%2.%3").arg(basename).arg(i).arg(extension);
+        if (!info.dir().exists(filename))
+            return info.dir().filePath(filename);
+    }
+    return filePath;
+}
+
+QString Util::trcString(int trc)
+{
+    QString trcString = QObject::tr("unknown (%1)").arg(trc);
+    switch (trc) {
+    case 0:
+        trcString = QObject::tr("NA");
+        break;
+    case 1:
+        trcString = "ITU-R BT.709";
+        break;
+    case 6:
+        trcString = "ITU-R BT.601";
+        break;
+    case 7:
+        trcString = "SMPTE ST240";
+        break;
+    case 11:
+        trcString = "IEC 61966-2-4";
+        break;
+    case 13:
+        trcString = "sRGB";
+        break;
+    case 14:
+        trcString = "ITU-R BT.2020";
+        break;
+    case 15:
+        trcString = "ITU-R BT.2020";
+        break;
+    case 16:
+        trcString = "SMPTE ST2084 (PQ)";
+        break;
+    case 17:
+        trcString = "SMPTE ST428";
+        break;
+    case 18:
+        trcString = "ARIB B67 (HLG)";
+        break;
+    }
+    return trcString;
+}
+
+bool Util::trcIsCompatible(int trc)
+{
+    // Transfer characteristics > SMPTE240M Probably need conversion except IEC61966-2-4 is OK
+    return trc <= 7 || trc == 11 || trc == 13 || trc == 18;
+}
+
+QString Util::getConversionAdvice(Mlt::Producer *producer)
+{
+    QString advice;
+    producer->probe();
+    QString resource = Util::GetFilenameFromProducer(producer);
+    int trc = producer->get_int("meta.media.color_trc");
+    if (!Util::trcIsCompatible(trc)) {
+        QString trcString = Util::trcString(trc);
+        LOG_INFO() << resource << "Probable HDR" << trcString;
+        advice = QObject::tr("This file uses color transfer characteristics %1, which may result in incorrect colors or brightness in Shotcut.").arg(
+                     trcString);
+    } else if (producer->get_int("meta.media.variable_frame_rate")) {
+        LOG_INFO() << resource << "is variable frame rate";
+        advice = QObject::tr("This file is variable frame rate, which is not reliable for editing.");
+    } else if (QFile::exists(resource) && !MLT.isSeekable(producer)) {
+        LOG_INFO() << resource << "is not seekable";
+        advice = QObject::tr("This file does not support seeking and cannot be used for editing.");
+    } else if (QFile::exists(resource) && resource.endsWith(".m2t")) {
+        LOG_INFO() << resource << "is HDV";
+        advice = QObject::tr("This file format (HDV) is not reliable for editing.");
+    }
+    return advice;
+}
+
+mlt_color Util::mltColorFromQColor(const QColor &color)
+{
+    return mlt_color {
+        static_cast<uint8_t>(color.red()),
+        static_cast<uint8_t>(color.green()),
+        static_cast<uint8_t>(color.blue()),
+        static_cast<uint8_t>(color.alpha())
+    };
+}
+
+void Util::offerSingleFileConversion(QString &message, Mlt::Producer *producer, QWidget *parent)
+{
+    TranscodeDialog dialog(message.append(
+                               QObject::tr(" Do you want to convert it to an edit-friendly format?\n\n"
+                                           "If yes, choose a format below and then click OK to choose a file name. "
+                                           "After choosing a file name, a job is created. "
+                                           "When it is done, it automatically replaces clips, or you can double-click the job to open it.\n")),
+                           producer->get_int("progressive"), parent);
+    dialog.setWindowModality(QmlApplication::dialogModality());
+    dialog.showCheckBox();
+    dialog.set709Convert(!Util::trcIsCompatible(producer->get_int("meta.media.color_trc")));
+    dialog.showSubClipCheckBox();
+    LOG_DEBUG() << "in" << producer->get_in() << "out" << producer->get_out() << "length" <<
+                producer->get_length() - 1;
+    dialog.setSubClipChecked(producer->get_in() > 0
+                             || producer->get_out() < producer->get_length() - 1);
+    Transcoder transcoder;
+    transcoder.addProducer(producer);
+    transcoder.convert(dialog);
+}
